package util

import groovy.transform.Memoized

class GlobalProperties {

    @Memoized
    static loadGlobalProperties() {
        def propertiesFiles = System.findGlobalPropertyList("${CIProperties.CI_PROPERTIES_PREFIX}.properties.file.locations")
            .orElse([".ci/ci.properties"])
            .map { new File(it) }

        if (propertiesFiles.isNotNullOrEmpty()) {
            propertiesFiles.forEach { propertiesFile ->
                if (propertiesFile.exists()) {
                    loadPropertiesFile(propertiesFile)
                } else {
                    ScriptLog.printf "Skipping non-existing properties file '${propertiesFile.absoluteCanonicalFile.path}'!"
                }
            }
        }
    }

    static void loadPropertiesFile(File propertiesFile) {
        if (propertiesFile == null) {
            return
        }

        if (!propertiesFile.exists()) {
            throw new IOException("Could not find properties file '${propertiesFile}' (with absolute path: '${propertiesFile.absoluteCanonicalFile.path}')!")
        }

        if (propertiesFile.isDirectory()) {
            throw new IOException("Directory found instead properties file '${propertiesFile}' (with absolute path: '${propertiesFile.absoluteCanonicalFile.path}')!")
        }

        System.registerGlobalConfiguration(propertiesFile)
    }
}
